#include <gtk--.h>
#ifdef HAVE_CONFIG_H
#include <config.h>
#endif

#include <string>

class test : public Gtk_Window {
protected:
  Gtk_EventBox ebox;
  Gtk_VBox vbox;
  Gtk_Button closebutton;
  Gtk_HSeparator hsep;
public:
  test();
  gint delete_event_impl(GdkEventAny*);
  void add(Gtk_Widget &w) { vbox.pack_start(w,FALSE,FALSE,0); }
};

class togglebuttontest : public test {
    Gtk_ToggleButton tb,tb2;
public:
    togglebuttontest();
};

class timertest : public test {
    Gtk_Button b;
    Gtk_Label l;
    gint flag;
    bool state;
public:
    void show_impl();
    void hide_impl();
    timertest();
    void startit();
    void stopit();
    gint tick();
};

class menufactorytest : public test {
  Gtk_MenuBar *mb;
  Gtk_MenuFactory mf;
  Gtk_MenuFactory subfactory;
public:
  menufactorytest(void);
  void menucallback(char* data);
};

#if GTK_MAJOR_VERSION > 1 || ( GTK_MAJOR_VERSION == 1 && GTK_MINOR_VERSION >= 1)
class ItemFactoryTest : public test {
public:
  ItemFactoryTest(void);
  void itemcallback(string m);
private:
  gint buttonPress( GdkEventButton * event);
  Gtk_ItemFactory *itemf;
  //Gtk_MenuBar     *mb;
  Gtk_ObjectHandle<Gtk_MenuBar> mb;
  Gtk_ItemFactory              *popupFactory;
  Gtk_ObjectHandle<Gtk_Menu>    popupMenu;
};
#endif

class dummy 
{
  char * s;
  
public:
  void method_char(char *data);
  void method_int(int i);
  void method_noarg(void);
  dummy(char *_s) : s(_s) {};
};



class chooser : public Gtk_Window {
    Gtk_VBox vbox;
public:
    chooser();
    gint delete_event_impl(GdkEventAny* e);
    void add_item(const char *name, test *widget);
};
